import unittest
from num2geotext.float_num_to_geo_currency import *


class FloatToCurrency(unittest.TestCase):

    def test_float_to_currency(self):
        self.assertEqual(float_num_to_geo_currency(0.365), "ოცდაჩვიდმეტი თეთრი")
        self.assertEqual(float_num_to_geo_currency(4.2), "ოთხი ლარი და ოცი თეთრი")
        self.assertEqual(float_num_to_geo_currency(17.254), "ჩვიდმეტი ლარი და ოცდახუთი თეთრი")
        self.assertEqual(float_num_to_geo_currency(356.8), "სამას ორმოცდათექვსმეტი ლარი და ოთხმოცი თეთრი")
        self.assertEqual(float_num_to_geo_currency(3_106.4449), "სამი ათას ას ექვსი ლარი და ორმოცდაოთხი თეთრი")
        self.assertEqual(float_num_to_geo_currency(10_006.05), "ათი ათას ექვსი ლარი და ხუთი თეთრი")
        self.assertEqual(float_num_to_geo_currency(325_459.4), "სამას ოცდახუთი ათას ოთხას ორმოცდაცხრამეტი ლარი და ორმოცი თეთრი")
        self.assertEqual(float_num_to_geo_currency(4_512_100.25), "ოთხი მილიონ ხუთას თორმეტი ათას ასი ლარი და ოცდახუთი თეთრი")
        self.assertEqual(float_num_to_geo_currency(68_124_432.3), "სამოცდარვა მილიონ ას ოცდაოთხი ათას ოთხას ოცდათორმეტი ლარი და ოცდაათი თეთრი")
        self.assertEqual(float_num_to_geo_currency(325_000_000.999), "სამას ოცდახუთი მილიონ ერთი ლარი და ნული თეთრი")
        self.assertEqual(float_num_to_geo_currency(1_815_030_020.9), "ერთი მილიარდ რვაას თხუთმეტი მილიონ ოცდაათი ათას ოცი ლარი და ოთხმოცდაათი თეთრი")
        self.assertEqual(float_num_to_geo_currency(15_834_230_110.5), "თხუთმეტი მილიარდ რვაას ოცდათოთხმეტი მილიონ ორას ოცდაათი ათას ას ათი ლარი და ორმოცდაათი თეთრი")
        self.assertEqual(float_num_to_geo_currency(332_214_110_160.23), "სამას ოცდათორმეტი მილიარდ ორას თოთხმეტი მილიონ ას ათი ათას ას სამოცი ლარი და ოცდასამი თეთრი")
        self.assertEqual(float_num_to_geo_currency(6_452_323_784_001.9223), "ექვსი ტრილიონ ოთხას ორმოცდათორმეტი მილიარდ სამას ოცდასამი მილიონ შვიდას ოთხმოცდაოთხი ათას ერთი ლარი და ოთხმოცდათორმეტი თეთრი")
        self.assertEqual(float_num_to_geo_currency(10_000_000_000_000.001), "ათი ტრილიონი ლარი და ნული თეთრი")
        self.assertEqual(float_num_to_geo_currency(100_020_001_030_004.22), "ასი ტრილიონ ოცი მილიარდ ერთი მილიონ ოცდაათი ათას ოთხი ლარი და ოცდაორი თეთრი")




from num2geotext.number_to_word import num_text


def one_or_two_digit_int_number(number: int) -> str:
    num = str(number)
    if len(num) == 1 or len(num) == 2:
      return f'{num_text[int(num[:])]}'
    else:
      raise ValueError("Not supported! The whole number must have one or two digits.")


def three_digit_int_number(number: int) -> str:
    num = str(number)
    if len(num) == 3:
      if num[0] == '1':
          if num[1:] == '00':
              return 'ასი'
          return f'ას {num_text[int(num[1:])]}'
      elif num_text[int(num[0])].endswith('ი') and num[1:] == '00':
          return f'{num_text[int(num[0])][:-1]}ასი'
      elif num_text[int(num[0])].endswith('ი') and num[1:] != '00':
          return f'{num_text[int(num[0])][:-1]}ას {one_or_two_digit_int_number(int(num[1:]))}'
      elif num_text[int(num[0])].endswith('ი') == False and num[1:] == '00':
          return f'{num_text[int(num[0])]}ასი'
      elif num_text[int(num[0])].endswith('ი') == False:
          return f'{num_text[int(num[0])]}ას {one_or_two_digit_int_number(int(num[1:]))}'
    else:
      raise ValueError("Not supported! The whole number must have three digits.")


def four_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 4:
    if num[0] == '1':
      if num[1:] == '000':
        return 'ათასი'
      elif num[1] == '1':
        return f'ათას ას {one_or_two_digit_int_number(int(num[2:]))}'
      elif num[1] == '0':
        return f'ათას {one_or_two_digit_int_number(int(num[2:]))}'
      else:
        return f'ათას {three_digit_int_number(int(num[1:]))}'
    elif num[0] != 1 and num[1] == '0' and num[2:] != '00':
      return f'{num_text[int(num[0])]} ათას {one_or_two_digit_int_number(int(num[2:]))}'
    elif num[0] != 1 and num[1:] == '000':
      return f'{num_text[int(num[0])]} ათასი'
    else:
      return f'{num_text[int(num[0])]} ათას {three_digit_int_number(int(num[1:]))}'
  else:
    raise ValueError("Not supported! The whole number must have four digits.")


def five_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 5:
    if num[2:] == '000':
      return f'{num_text[int(num[:2])]} ათასი'
    elif num[2] == '0' and num[3:] != '00':
      return f'{num_text[int(num[:2])]} ათას {one_or_two_digit_int_number(int(num[3:]))}'
    return f'{num_text[int(num[:2])]} ათას {three_digit_int_number(int(num[2:]))}'
  else:
    raise ValueError("Not supported! The whole number must have five digits.")


def six_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 6:
    if num[3:] == '000':
      return f'{three_digit_int_number(int(num[0:3]))} ათასი'
    elif num[3:5] == '00' and num[5] != 0:
      return f'{three_digit_int_number(int(num[0:3]))} ათას {one_or_two_digit_int_number(int(num[5:]))}'
    elif num[3] == '0' and num[4:] != '00':
      return f'{three_digit_int_number(int(num[0:3]))} ათას {one_or_two_digit_int_number(int(num[3:]))}'
    else:
      return f'{three_digit_int_number(int(num[0:3]))} ათას {three_digit_int_number(int(num[3:]))}'
  else:
    raise ValueError("Not supported! The whole number must have six digits.")


def seven_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 7:
    if num[1:] == '000000':
      return f'{num_text[int(num[0])]} მილიონი'
    elif num[1:5] == '0000':
      return f'{num_text[int(num[0])]} მილიონ {one_or_two_digit_int_number(int(num[5:]))}'
    elif num[1:4] == '000':
      return f'{num_text[int(num[0])]} მილიონ {three_digit_int_number(int(num[4:]))}'
    elif num[1:3] == '00':
      return f'{num_text[int(num[0])]} მილიონ {four_digit_int_number(int(num[3:]))}'
    elif num[1] == '0':
      return f'{num_text[int(num[0])]} მილიონ {five_digit_int_number(int(num[2:]))}'
    else:
      return f'{num_text[int(num[0])]} მილიონ {six_digit_int_number(int(num[1:]))}'
  else:
    raise ValueError("Not supported! The whole number must have seven digits.")


def eight_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 8:
    if num[2:] == '000000':
      return f'{one_or_two_digit_int_number(int(num[0:2]))} მილიონი'
    elif num[2:6] == '0000':
      return f'{one_or_two_digit_int_number(int(num[0:2]))} მილიონ {one_or_two_digit_int_number(int(num[6:]))}'
    elif num[2:5] == '000':
      return f'{one_or_two_digit_int_number(int(num[0:2]))} მილიონ {three_digit_int_number(int(num[5:]))}'
    elif num[2:4] == '00':
      return f'{one_or_two_digit_int_number(int(num[0:2]))} მილიონ {four_digit_int_number(int(num[4:]))}'
    elif num[2] == '0':
      return f'{one_or_two_digit_int_number(int(num[0:2]))} მილიონ {five_digit_int_number(int(num[3:]))}'
    else:
      return f'{one_or_two_digit_int_number(int(num[0:2]))} მილიონ {six_digit_int_number(int(num[2:]))}'
  else:
    raise ValueError("Not supported! The whole number must have eight digits.")


def nine_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 9:
    if num[3:] == '000000':
      return f'{three_digit_int_number(int(num[0:3]))} მილიონი'
    elif num[3:7] == '0000':
      return f'{three_digit_int_number(int(num[0:3]))} მილიონ {one_or_two_digit_int_number(int(num[7:]))}'
    elif num[3:6] == '000':
      return f'{three_digit_int_number(int(num[0:3]))} მილიონ {three_digit_int_number(int(num[6:]))}'
    elif num[3:5] == '00':
      return f'{three_digit_int_number(int(num[0:3]))} მილიონ {four_digit_int_number(int(num[5:]))}'
    elif num[3] == '0':
      return f'{three_digit_int_number(int(num[0:3]))} მილიონ {five_digit_int_number(int(num[4:]))}'
    else:
      return f'{three_digit_int_number(int(num[0:3]))} მილიონ {six_digit_int_number(int(num[3:]))}'
  else:
    raise ValueError("Not supported! The whole number must have nine digits.")


def ten_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 10:
    if num[1:] == '000000000':
      return f'{num_text[int(num[0])]} მილიარდი'
    elif num[1:8] == '0000000':
      return f'{num_text[int(num[0])]} მილიარდ {one_or_two_digit_int_number(int(num[8:]))}'
    elif num[1:7] == '000000':
      return f'{num_text[int(num[0])]} მილიარდ {three_digit_int_number(int(num[7:]))}'
    elif num[1:6] == '00000':
      return f'{num_text[int(num[0])]} მილიარდ {four_digit_int_number(int(num[6:]))}'
    elif num[1:5] == '0000':
      return f'{num_text[int(num[0])]} მილიარდ {five_digit_int_number(int(num[5:]))}'
    elif num[1:4] == '000':
      return f'{num_text[int(num[0])]} მილიარდ {six_digit_int_number(int(num[4:]))}'
    elif num[1:3] == '00':
      return f'{num_text[int(num[0])]} მილიარდ {seven_digit_int_number(int(num[3:]))}'
    elif num[1:2] == '0':
      return f'{num_text[int(num[0])]} მილიარდ {eight_digit_int_number(int(num[2:]))}'
    else:
      return f'{num_text[int(num[0])]} მილიარდ {nine_digit_int_number(int(num[1:]))}'
  else:
    raise ValueError("Not supported! The whole number must have ten digits.")


def eleven_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 11:
    if num[1:] == '0000000000':
      return f'{num_text[int(num[0:2])]} მილიარდი'
    elif num[1:9] == '00000000':
      return f'{num_text[int(num[0:2])]} მილიარდ {one_or_two_digit_int_number(int(num[9:]))}'
    elif num[1:8] == '0000000':
      return f'{num_text[int(num[0:2])]} მილიარდ {three_digit_int_number(int(num[8:]))}'
    elif num[1:7] == '000000':
      return f'{num_text[int(num[0:2])]} მილიარდ {four_digit_int_number(int(num[7:]))}'
    elif num[1:6] == '00000':
      return f'{num_text[int(num[0:2])]} მილიარდ {five_digit_int_number(int(num[6:]))}'
    elif num[1:5] == '0000':
      return f'{num_text[int(num[0:2])]} მილიარდ {six_digit_int_number(int(num[5:]))}'
    elif num[1:4] == '000':
      return f'{num_text[int(num[0:2])]} მილიარდ {seven_digit_int_number(int(num[4:]))}'
    elif num[1:3] == '00':
      return f'{num_text[int(num[0:2])]} მილიარდ {eight_digit_int_number(int(num[3:]))}'
    else:
      return f'{num_text[int(num[0:2])]} მილიარდ {nine_digit_int_number(int(num[2:]))}'
  else:
    raise ValueError("Not supported! The whole number must have eleven digits.")


def twelve_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 12:
    if num[3:] == '000000000':
      return f'{three_digit_int_number(int(num[:3]))} მილიარდი'
    elif num[3:10] == '0000000':
      return f'{three_digit_int_number(int(num[:3]))} მილიარდ {one_or_two_digit_int_number(int(num[10:]))}'
    elif num[3:9] == '000000':
      return f'{three_digit_int_number(int(num[:3]))} მილიარდ {three_digit_int_number(int(num[9:]))}'
    elif num[3:8] == '00000':
      return f'{three_digit_int_number(int(num[:3]))} მილიარდ {four_digit_int_number(int(num[8:]))}'
    elif num[3:7] == '0000':
      return f'{three_digit_int_number(int(num[:3]))} მილიარდ {five_digit_int_number(int(num[7:]))}'
    elif num[3:6] == '000':
      return f'{three_digit_int_number(int(num[:3]))} მილიარდ {six_digit_int_number(int(num[6:]))}'
    elif num[3:5] == '00':
      return f'{three_digit_int_number(int(num[:3]))} მილიარდ {seven_digit_int_number(int(num[5:]))}'
    elif num[3:4] == '0':
      return f'{three_digit_int_number(int(num[:3]))} მილიარდ {eight_digit_int_number(int(num[4:]))}'
    else:
      return f'{three_digit_int_number(int(num[:3]))} მილიარდ {nine_digit_int_number(int(num[3:]))}'
  else:
    raise ValueError("Not supported! The whole number must have twelve digits.")


def thirteen_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 13:
    if num[1:] == '000000000000':
      return f'{num_text[int(num[0])]} ტრილიონი'
    elif num[1:11] == '0000000000':
      return f'{num_text[int(num[0])]} ტრილიონ {one_or_two_digit_int_number(int(num[11:]))}'
    elif num[1:10] == '000000000':
      return f'{num_text[int(num[0])]} ტრილიონ {three_digit_int_number(int(num[10:]))}'
    elif num[1:9] == '00000000':
      return f'{num_text[int(num[0])]} ტრილიონ {four_digit_int_number(int(num[9:]))}'
    elif num[1:8] == '0000000':
      return f'{num_text[int(num[0])]} ტრილიონ {five_digit_int_number(int(num[8:]))}'
    elif num[1:7] == '000000':
      return f'{num_text[int(num[0])]} ტრილიონ {six_digit_int_number(int(num[7:]))}'
    elif num[1:6] == '00000':
      return f'{num_text[int(num[0])]} ტრილიონ {seven_digit_int_number(int(num[6:]))}'
    elif num[1:5] == '0000':
      return f'{num_text[int(num[0])]} ტრილიონ {eight_digit_int_number(int(num[5:]))}'
    elif num[1:4] == '000':
      return f'{num_text[int(num[0])]} ტრილიონ {nine_digit_int_number(int(num[4:]))}'
    elif num[1:3] == '00':
      return f'{num_text[int(num[0])]} ტრილიონ {ten_digit_int_number(int(num[3:]))}'
    elif num[1:2] == '0':
      return f'{num_text[int(num[0])]} ტრილიონ {eleven_digit_int_number(int(num[2:]))}'
    else:
      return f'{num_text[int(num[0])]} ტრილიონ {twelve_digit_int_number(int(num[1:]))}'
  else:
    raise ValueError("Not supported! The whole number must have thirteen digits.")


def fourteen_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 14:
    if num[2:] == '000000000000':
      return f'{num_text[int(num[0:2])]} ტრილიონი'
    elif num[1:12] == '00000000000':
      return f'{num_text[int(num[0:2])]} ტრილიონ {one_or_two_digit_int_number(int(num[12:]))}'
    elif num[1:11] == '0000000000':
      return f'{num_text[int(num[0:2])]} ტრილიონ {three_digit_int_number(int(num[11:]))}'
    elif num[1:10] == '000000000':
      return f'{num_text[int(num[0:2])]} ტრილიონ {four_digit_int_number(int(num[10:]))}'
    elif num[1:9] == '00000000':
      return f'{num_text[int(num[0:2])]} ტრილიონ {five_digit_int_number(int(num[9:]))}'
    elif num[1:8] == '0000000':
      return f'{num_text[int(num[0:2])]} ტრილიონ {six_digit_int_number(int(num[8:]))}'
    elif num[1:7] == '000000':
      return f'{num_text[int(num[0:2])]} ტრილიონ {seven_digit_int_number(int(num[7:]))}'
    elif num[1:6] == '00000':
      return f'{num_text[int(num[0:2])]} ტრილიონ {eight_digit_int_number(int(num[6:]))}'
    elif num[1:5] == '0000':
      return f'{num_text[int(num[0:2])]} ტრილიონ {nine_digit_int_number(int(num[5:]))}'
    elif num[1:4] == '000':
      return f'{num_text[int(num[0:2])]} ტრილიონ {ten_digit_int_number(int(num[4:]))}'
    elif num[1:3] == '00':
      return f'{num_text[int(num[0:2])]} ტრილიონ {eleven_digit_int_number(int(num[3:]))}'
    else:
      return f'{num_text[int(num[0:2])]} ტრილიონ {twelve_digit_int_number(int(num[2:]))}'
  else:
    raise ValueError("Not supported! The whole number must have fourteen digits.")


def fifteen_digit_int_number(number: int) -> str:
  num = str(number)

  if len(num) == 15:
    if num[3:] == '000000000000':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონი'
    elif num[3:13] == '0000000000':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {one_or_two_digit_int_number(int(num[13:]))}'
    elif num[3:12] == '000000000':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {three_digit_int_number(int(num[12:]))}'
    elif num[3:11] == '00000000':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {four_digit_int_number(int(num[11:]))}'
    elif num[3:10] == '0000000':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {five_digit_int_number(int(num[10:]))}'
    elif num[3:9] == '000000':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {six_digit_int_number(int(num[9:]))}'
    elif num[3:8] == '00000':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {seven_digit_int_number(int(num[8:]))}'
    elif num[3:7] == '0000':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {eight_digit_int_number(int(num[7:]))}'
    elif num[3:6] == '000':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {nine_digit_int_number(int(num[6:]))}'
    elif num[3:5] == '00':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {ten_digit_int_number(int(num[5:]))}'
    elif num[3:4] == '0':
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {eleven_digit_int_number(int(num[4:]))}'
    else:
      return f'{three_digit_int_number(int(num[0:3]))} ტრილიონ {twelve_digit_int_number(int(num[3:]))}'
  else:
    raise ValueError("Not supported! The whole number must have fifteen digits.")


def int_num_to_geo_text(number: int) -> str:
    num = str(number)
    num_len = len(num)

    if num_len == 1 or num_len == 2:
        return one_or_two_digit_int_number(number)
    elif num_len == 3:
        return three_digit_int_number(number)
    elif num_len == 4:
        return four_digit_int_number(number)
    elif num_len == 5:
        return five_digit_int_number(number)
    elif num_len == 6:
        return six_digit_int_number(number)
    elif num_len == 7:
        return seven_digit_int_number(number)
    elif num_len == 8:
        return eight_digit_int_number(number)
    elif num_len == 9:
        return nine_digit_int_number(number)
    elif num_len == 10:
        return ten_digit_int_number(number)
    elif num_len == 11:
        return eleven_digit_int_number(number)
    elif num_len == 12:
        return twelve_digit_int_number(number)
    elif num_len == 13:
        return thirteen_digit_int_number(number)
    elif num_len == 14:
        return fourteen_digit_int_number(number)
    elif num_len == 15:
        return fifteen_digit_int_number(number)
    else:
        raise ValueError("Not supported! The maximum allowable digits is 15")




from num2geotext.int_num_to_geo_text import one_or_two_digit_int_number, three_digit_int_number, four_digit_int_number, five_digit_int_number, six_digit_int_number, seven_digit_int_number, eight_digit_int_number, nine_digit_int_number, ten_digit_int_number, eleven_digit_int_number, twelve_digit_int_number, thirteen_digit_int_number, fourteen_digit_int_number, fifteen_digit_int_number
from num2geotext.float_num_to_geo_text import custom_round


def one_or_two_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has either one or two digits before the decimal point.")

  if (num.index('.') == 1 or num.index('.') == 2) and len(num) >= 5:
    num = str(custom_round(float(num), 2))
  if custom_round(float(num), 2) == 100.0:
    return f"ასი ლარი და ნული თეთრი"
  elif num.index('.') == 1 and num[0] == '0' and custom_round(float(num), 2) != 1.0 and len(num[num.index('.') + 1:]) == 1:
    return f"{one_or_two_digit_int_number(int(num[-1] + '0'))} თეთრი"
  elif num.index('.') == 1 and num[0] == '0' and custom_round(float(num), 2) != 1.0 and len(num[num.index('.') + 1:]) == 2:
    return f"{one_or_two_digit_int_number(int(num[num.index('.') + 1:]))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{one_or_two_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[-1] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{one_or_two_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1:]))} თეთრი"
  else:
    return None


def three_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has three digits before the decimal point.")

  if num.index('.') == 3 and len(num) > 6:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 1000.0:
    return f"ათასი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{three_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{three_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def four_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has four digits before the decimal point.")

  if num.index('.') == 4 and len(num) > 7:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 10_000.0:
    return f"ათი ათასი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{four_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{four_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def five_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has five digits before the decimal point.")

  if num.index('.') == 5 and len(num) > 8:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 100_000:
    return f"ასი ათასი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{five_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{five_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def six_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has six digits before the decimal point.")

  if num.index('.') == 6 and len(num) > 9:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 1_000_000:
    return f"ერთი მილიონი ლარი და ნული თეთრი"
  if len(num[num.index('.') + 1:]) == 1:
    return f"{six_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{six_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def seven_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has seven digits before the decimal point.")

  if num.index('.') == 7 and len(num) > 10:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 10_000_000:
    return f"ათი მილიონი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{seven_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{seven_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def eight_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has eight digits before the decimal point.")

  if num.index('.') == 8 and len(num) > 11:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 100_000_000:
    return f"ასი მილიონი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{eight_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{eight_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def nine_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has nine digits before the decimal point.")

  if num.index('.') == 9 and len(num) > 12:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 1_000_000_000:
    return f"ერთი მილიარდი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{nine_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{nine_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def ten_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has ten digits before the decimal point.")

  if num.index('.') == 10 and len(num) > 13:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 10_000_000_000:
    return f"ათი მილიარდი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{ten_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{ten_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def eleven_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has eleven digits before the decimal point.")

  if num.index('.') == 11 and len(num) > 14:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 100_000_000_000:
    return f"ასი მილიარდი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{eleven_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{eleven_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def twelve_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has twelve digits before the decimal point.")

  if num.index('.') == 12 and len(num) > 15:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 1_000_000_000_000:
    return f"ერთი ტრილიონი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{twelve_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{twelve_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def thirteen_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has thirteen digits before the decimal point.")

  if num.index('.') == 13 and len(num) > 16:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 10_000_000_000_000:
    return f"ათი ტრილიონი ლარი და ნული თეთრი"
  if len(num[num.index('.') + 1:]) == 1:
    return f"{thirteen_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{thirteen_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def fourteen_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has fourteen digits before the decimal point.")

  if num.index('.') == 14 and len(num) > 17:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 100_000_000_000_000:
    return f"ასი ტრილიონი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{fourteen_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{fourteen_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None


def fifteen_digit_float_number_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has fifteen digits before the decimal point.")

  if num.index('.') == 15 and len(num) > 18:
    num = str(custom_round(float(num), 2))

  if custom_round(float(num), 2) == 1_000_000_000_000_000:
    return f"ერთი კუადრილიონი ლარი და ნული თეთრი"
  elif len(num[num.index('.') + 1:]) == 1:
    return f"{fifteen_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :] + '0'))} თეთრი"
  elif len(num[num.index('.') + 1:]) == 2:
    return f"{fifteen_digit_int_number(int(num[:num.index('.')]))} ლარი და {one_or_two_digit_int_number(int(num[num.index('.') + 1 :]))} თეთრი"
  else:
    return None



def float_num_to_geo_currency(number: float) -> str:
  if isinstance(number, float):
    num = str(number)
  else:
    raise ValueError(f"This function requires a float value that has a maximum of 15 digits before the decimal point.")

  if num.index('.') == 1 or num.index('.') == 2:
    return one_or_two_digit_float_number_currency(number)
  elif num.index('.') == 3:
    return three_digit_float_number_currency(number)
  elif num.index('.') == 4:
    return four_digit_float_number_currency(number)
  elif num.index('.') == 5:
    return five_digit_float_number_currency(number)
  elif num.index('.') == 6:
    return six_digit_float_number_currency(number)
  elif num.index('.') == 7:
    return seven_digit_float_number_currency(number)
  elif num.index('.') == 8:
    return eight_digit_float_number_currency(number)
  elif num.index('.') == 9:
    return nine_digit_float_number_currency(number)
  elif num.index('.') == 10:
    return ten_digit_float_number_currency(number)
  elif num.index('.') == 11:
    return eleven_digit_float_number_currency(number)
  elif num.index('.') == 12:
    return twelve_digit_float_number_currency(number)
  elif num.index('.') == 13:
    return thirteen_digit_float_number_currency(number)
  elif num.index('.') == 14:
    return fourteen_digit_float_number_currency(number)
  elif num.index('.') == 15:
    return fifteen_digit_float_number_currency(number)
  elif custom_round(float(num), 2) == 1_000_000_000_000_000:
    return f"ერთი კუადრილიონი ლარი და ნული თეთრი"
  else:
    raise ValueError(f"This function requires a float value that has a maximum of 15 digits before the decimal point.")




import unittest
from num2geotext.int_num_to_geo_text import int_num_to_geo_text


class IntToText(unittest.TestCase):

    def test_int_to_text(self):
        self.assertEqual(int_num_to_geo_text(1), "ერთი")
        self.assertEqual(int_num_to_geo_text(69), "სამოცდაცხრა")
        self.assertEqual(int_num_to_geo_text(543), "ხუთას ორმოცდასამი")
        self.assertEqual(int_num_to_geo_text(1_023), "ათას ოცდასამი")
        self.assertEqual(int_num_to_geo_text(52_160), "ორმოცდათორმეტი ათას ას სამოცი")
        self.assertEqual(int_num_to_geo_text(102_009), "ას ორი ათას ცხრა")
        self.assertEqual(int_num_to_geo_text(3_567_569), "სამი მილიონ ხუთას სამოცდაშვიდი ათას ხუთას სამოცდაცხრა")
        self.assertEqual(int_num_to_geo_text(40_352_900), "ორმოცი მილიონ სამას ორმოცდათორმეტი ათას ცხრაასი")
        self.assertEqual(int_num_to_geo_text(602_000_020), "ექვსას ორი მილიონ ოცი")
        self.assertEqual(int_num_to_geo_text(7_322_060_029), "შვიდი მილიარდ სამას ოცდაორი მილიონ სამოცი ათას ოცდაცხრა")
        self.assertEqual(int_num_to_geo_text(99_102_654_102), "ოთხმოცდაცხრამეტი მილიარდ ას ორი მილიონ ექვსას ორმოცდათოთხმეტი ათას ას ორი")
        self.assertEqual(int_num_to_geo_text(874_947_321_987), "რვაას სამოცდათოთხმეტი მილიარდ ცხრაას ორმოცდაშვიდი მილიონ სამას ოცდაერთი ათას ცხრაას ოთხმოცდაშვიდი")
        self.assertEqual(int_num_to_geo_text(6_245_131_890_163), "ექვსი ტრილიონ ორას ორმოცდახუთი მილიარდ ას ოცდათერთმეტი მილიონ რვაას ოთხმოცდაათი ათას ას სამოცდასამი")
        self.assertEqual(int_num_to_geo_text(32_112_526_341_962), "ოცდათორმეტი ტრილიონ ას თორმეტი მილიარდ ხუთას ოცდაექვსი მილიონ სამას ორმოცდაერთი ათას ცხრაას სამოცდაორი")
        self.assertEqual(int_num_to_geo_text(625_954_023_506_003), "ექვსას ოცდახუთი ტრილიონ ცხრაას ორმოცდათოთხმეტი მილიარდ ოცდასამი მილიონ ხუთას ექვსი ათას სამი")


if __name__ == "__main__":
    unittest.main()



import unittest
from num2geotext.float_num_to_geo_text import custom_round, float_num_to_geo_text



class FloatToText(unittest.TestCase):

    def test_float_to_text(self):
        self.assertEqual(custom_round(2.565, 2), 2.57)
        self.assertEqual(float_num_to_geo_text(0.246), "ნული მთელი, ოცდახუთი მეასედი")
        self.assertEqual(float_num_to_geo_text(13.2), "ცამეტი მთელი, ორი მეათედი")
        self.assertEqual(float_num_to_geo_text(648.193), "ექვსას ორმოცდარვა მთელი, ცხრამეტი მეასედი")
        self.assertEqual(float_num_to_geo_text(4_358.48), "ოთხი ათას სამას ორმოცდათვრამეტი მთელი, ორმოცდარვა მეასედი")
        self.assertEqual(float_num_to_geo_text(67_821.9), "სამოცდაშვიდი ათას რვაას ოცდაერთი მთელი, ცხრა მეათედი")
        self.assertEqual(float_num_to_geo_text(642_143.355), "ექვსას ორმოცდაორი ათას ას ორმოცდასამი მთელი, ოცდათექვსმეტი მეასედი")
        self.assertEqual(float_num_to_geo_text(1_354_982.102), "ერთი მილიონ სამას ორმოცდათოთხმეტი ათას ცხრაას ოთხმოცდაორი მთელი, ერთი მეათედი")
        self.assertEqual(float_num_to_geo_text(36_127_362.2), "ოცდათექვსმეტი მილიონ ას ოცდაშვიდი ათას სამას სამოცდაორი მთელი, ორი მეათედი")
        self.assertEqual(float_num_to_geo_text(437_248_149.76), "ოთხას ოცდაჩვიდმეტი მილიონ ორას ორმოცდარვა ათას ას ორმოცდაცხრა მთელი, სამოცდათექვსმეტი მეასედი")
        self.assertEqual(float_num_to_geo_text(9_424_123_578.10007), "ცხრა მილიარდ ოთხას ოცდაოთხი მილიონ ას ოცდასამი ათას ხუთას სამოცდათვრამეტი მთელი, ერთი მეათედი")
        self.assertEqual(float_num_to_geo_text(29_604_573_127.07), "ოცდაცხრა მილიარდ ექვსას ოთხი მილიონ ხუთას სამოცდაცამეტი ათას ას ოცდაშვიდი მთელი, შვიდი მეასედი")
        self.assertEqual(float_num_to_geo_text(354_000_000_007.12), "სამას ორმოცდათოთხმეტი მილიარდ შვიდი მთელი, თორმეტი მეასედი")
        self.assertEqual(float_num_to_geo_text(1_356_150_020_607.78), "ერთი ტრილიონ სამას ორმოცდათექვსმეტი მილიარდ ას ორმოცდაათი მილიონ ოცი ათას ექვსას შვიდი მთელი, სამოცდათვრამეტი მეასედი")
        self.assertEqual(float_num_to_geo_text(99_999_999_999_999.9999), "ასი ტრილიონი მთელი, ნული მეათედი")
        self.assertEqual(float_num_to_geo_text(944_256_021_357_149.5), "ცხრაას ორმოცდაოთხი ტრილიონ ორას ორმოცდათექვსმეტი მილიარდ ოცდაერთი მილიონ სამას ორმოცდაჩვიდმეტი ათას ას ორმოცდაცხრა მთელი, ხუთი მეათედი")


if __name__ == "__main__":
    unittest.main()


# Dictionary
num_text = {
    0: 'ნული',
    1: 'ერთი',
    2: 'ორი',
    3: 'სამი',
    4: 'ოთხი',
    5: 'ხუთი',
    6: 'ექვსი',
    7: 'შვიდი',
    8: 'რვა',
    9: 'ცხრა',
    10: 'ათი',
    11: 'თერთმეტი',
    12: 'თორმეტი',
    13: 'ცამეტი',
    14: 'თოთხმეტი',
    15: 'თხუთმეტი',
    16: 'თექვსმეტი',
    17: 'ჩვიდმეტი',
    18: 'თვრამეტი',
    19: 'ცხრამეტი',
    20: 'ოცი',
    21: 'ოცდაერთი',
    22: 'ოცდაორი',
    23: 'ოცდასამი',
    24: 'ოცდაოთხი',
    25: 'ოცდახუთი',
    26: 'ოცდაექვსი',
    27: 'ოცდაშვიდი',
    28: 'ოცდარვა',
    29: 'ოცდაცხრა',
    30: 'ოცდაათი',
    31: 'ოცდათერთმეტი',
    32: 'ოცდათორმეტი',
    33: 'ოცდაცამეტი',
    34: 'ოცდათოთხმეტი',
    35: 'ოცდათხუთმეტი',
    36: 'ოცდათექვსმეტი',
    37: 'ოცდაჩვიდმეტი',
    38: 'ოცდათვრამეტი',
    39: 'ოცდაცხრამეტი',
    40: 'ორმოცი',
    41: 'ორმოცდაერთი',
    42: 'ორმოცდაორი',
    43: 'ორმოცდასამი',
    44: 'ორმოცდაოთხი',
    45: 'ორმოცდახუთი',
    46: 'ორმოცდაექვსი',
    47: 'ორმოცდაშვიდი',
    48: 'ორმოცდარვა',
    49: 'ორმოცდაცხრა',
    50: 'ორმოცდაათი',
    51: 'ორმოცდათერთმეტი',
    52: 'ორმოცდათორმეტი',
    53: 'ორმოცდაცამეტი',
    54: 'ორმოცდათოთხმეტი',
    55: 'ორმოცდათხუთმეტი',
    56: 'ორმოცდათექვსმეტი',
    57: 'ორმოცდაჩვიდმეტი',
    58: 'ორმოცდათვრამეტი',
    59: 'ორმოცდაცხრამეტი',
    60: 'სამოცი',
    61: 'სამოცდაერთი',
    62: 'სამოცდაორი',
    63: 'სამოცდასამი',
    64: 'სამოცდაოთხი',
    65: 'სამოცდახუთი',
    66: 'სამოცდაექვსი',
    67: 'სამოცდაშვიდი',
    68: 'სამოცდარვა',
    69: 'სამოცდაცხრა',
    70: 'სამოცდაათი',
    71: 'სამოცდათერთმეტი',
    72: 'სამოცდათორმეტი',
    73: 'სამოცდაცამეტი',
    74: 'სამოცდათოთხმეტი',
    75: 'სამოცდათხუთმეტი',
    76: 'სამოცდათექვსმეტი',
    77: 'სამოცდაჩვიდმეტი',
    78: 'სამოცდათვრამეტი',
    79: 'სამოცდაცხრამეტი',
    80: 'ოთხმოცი',
    81: 'ოთხმოცდაერთი',
    82: 'ოთხმოცდაორი',
    83: 'ოთხმოცდასამი',
    84: 'ოთხმოცდაოთხი',
    85: 'ოთხმოცდახუთი',
    86: 'ოთხმოცდაექვსი',
    87: 'ოთხმოცდაშვიდი',
    88: 'ოთხმოცდარვა',
    89: 'ოთხმოცდაცხრა',
    90: 'ოთხმოცდაათი',
    91: 'ოთხმოცდათერთმეტი',
    92: 'ოთხმოცდათორმეტი',
    93: 'ოთხმოცდაცამეტი',
    94: 'ოთხმოცდათოთხმეტი',
    95: 'ოთხმოცდათხუთმეტი',
    96: 'ოთხმოცდათექვსმეტი',
    97: 'ოთხმოცდაჩვიდმეტი',
    98: 'ოთხმოცდათვრამეტი',
    99: 'ოთხმოცდაცხრამეტი',
    100: 'ასი'
}



from .number_to_word import num_text
from .int_num_to_geo_text import one_or_two_digit_int_number, three_digit_int_number, four_digit_int_number, five_digit_int_number, six_digit_int_number, seven_digit_int_number, nine_digit_int_number, ten_digit_int_number, eleven_digit_int_number, twelve_digit_int_number, thirteen_digit_int_number, fourteen_digit_int_number, fifteen_digit_int_number, int_num_to_geo_text
from .float_num_to_geo_text import custom_round, one_or_two_digit_float_number, three_digit_float_number, four_digit_float_number, five_digit_float_number, six_digit_float_number, seven_digit_float_number, eight_digit_float_number, nine_digit_float_number, ten_digit_float_number, eleven_digit_float_number, twelve_digit_float_number, thirteen_digit_float_number, fourteen_digit_float_number, fifteen_digit_float_number, float_num_to_geo_text
from .float_num_to_geo_currency import one_or_two_digit_float_number_currency, three_digit_float_number_currency, four_digit_float_number_currency, five_digit_float_number_currency, six_digit_float_number_currency, seven_digit_float_number_currency, eight_digit_float_number_currency, nine_digit_float_number_currency, ten_digit_float_number_currency, eleven_digit_float_number_currency, twelve_digit_float_number_currency, thirteen_digit_float_number_currency, fourteen_digit_float_number_currency, fifteen_digit_float_number_currency, float_num_to_geo_currency




from setuptools import setup, find_packages

VERSION = '0.0.1'
DESCRIPTION = '''
A Python package for converting numbers and floats (up to 15 digits) into Georgian text, 
and for converting floats (up to 15 digits) into Georgian currency text representations.
'''
LONG_DESCRIPTION = ('''
num2geotext is a python package for converting numbers and floats into text, 
and for converting floats into currency text representations. It supports a wide range of use cases, 
including converting numerical values for text-based reports, financial applications, 
educational tools, voice assistants, legal documents, and data validation. 
This package can be utilized in generating invoices, converting currency amounts for receipts, 
enhancing accessibility through text-to-speech systems, and providing better readability for 
large numeric data.
''')

# Setting up
setup(
        name="num2geotext",
        version=VERSION,
        author="Tornike Skhirtladze",
        author_email="<skhirtladze.tornike@gmail.com>",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=[],
        keywords=[
            'python',
            'number to text',
            'float to text',
            'float to currency text',
            'Georgian language',
            'Georgian text',
            'Georgian currency',
            'text conversion',
            'number to words',
            'text processing',
            'numerical data conversion',
            'text-based reports',
            'financial applications',
            'educational tools',
            'data validation',
            'legal documents'
        ],
        classifiers= [
            "Development Status :: 4 - Beta",
            "Intended Audience :: Developers",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.7",
            "Programming Language :: Python :: 3.8",
            "Programming Language :: Python :: 3.9",
            "Programming Language :: Python :: 3.10",
            "Programming Language :: Python :: 3.11",
            "Natural Language :: Georgian",
            "Topic :: Text Processing :: Linguistic",
            "Operating System :: OS Independent"
        ]
)
